summaryrefslogtreecommitdiffstats
path: root/karbon/commands/vshapecmd.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /karbon/commands/vshapecmd.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'karbon/commands/vshapecmd.h')
-rw-r--r--karbon/commands/vshapecmd.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/karbon/commands/vshapecmd.h b/karbon/commands/vshapecmd.h
index dc033dbe..30607fcd 100644
--- a/karbon/commands/vshapecmd.h
+++ b/karbon/commands/vshapecmd.h
@@ -28,13 +28,13 @@ class VPath;
/*
* Provides a common base class for creation commands since they all have
* a similar execute / unexecute behaviour and all build a VPath. Upon
* execution() the shape will be added to the document and selected, upon undoing
* it will be set to the deleted state.
*/
class KARBONCOMMAND_EXPORT VShapeCmd : public VCommand
{
public:
- VShapeCmd( VDocument* doc, const QString& name, VPath* shape, const QString& icon = "14_polygon" );
+ VShapeCmd( VDocument* doc, const TQString& name, VPath* tqshape, const TQString& icon = "14_polygon" );
virtual ~VShapeCmd() {}
virtual void execute();
@@ -43,8 +43,8 @@ public:
virtual bool changesSelection() const { return true; }
protected:
- /// Pointer to the created shape.
- VPath *m_shape;
+ /// Pointer to the created tqshape.
+ VPath *m_tqshape;
};
#endif
@@ -28,13 +28,13 @@ class VPath;
* Provides a common base class for creation commands since they all have
* a similar execute / unexecute behaviour and all build a VPath. Upon
- * execution() the shape will be added to the document and selected, upon undoing
+ * execution() the tqshape will be added to the document and selected, upon undoing
* it will be set to the deleted state.
*/